@@ -7,8 +7,7 @@ use Carp;
 has callback         => (is => 'rw', required => 1);
 has host             => (is => 'rw', required => 1);
 has ssh_options      => (is => 'rw', default => sub { {} });
-has ssh              => (is => 'rw', lazy => 1, builder => 1);
-has connect_attempts => (is => 'rw', default => sub { 3 });
+has ssh              => (is => 'rw', lazy => 1, builder => 1, clearer => 1);
 
 sub _build_ssh {
     my $self = shift;
@@ -22,17 +21,19 @@ sub _build_ssh {
 # force ssh builder to run so the connection occurs during object instantiation
 sub BUILD { shift->ssh }
 
+sub reconnect {
+    my $self = shift;
+    $self->clear_ssh;
+    $self->ssh;
+}
+
 sub run {
     my ($self, @cmd) = @_;
 
     $self->callback->('command', $self->_stringify(@cmd), $self->host);
 
     my ($pty, $pid) = $self->ssh->open2pty(@cmd);
-    if (!$pty || $self->ssh->error) {
-        $self->clear_ssh; # force new connection to the server
-        ($pty, $pid) = $self->ssh->open2pty(@cmd);
-        die $self->ssh->error if $self->ssh->error;
-    }
+    die $self->ssh->error if $self->ssh->error;
 
     while (my $line = <$pty>) {
       $line =~ s/([\r\n])$//g;
